==> nzbget-0.2.0.tar.gz: nzbget-0.2.0/NZBQueueMessageControl.h <==
/*
 *  This file if part of nzbget
 *
 *  Copyright (C) 2005  Bo Cordes Petersen <placebodk@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Revision: 1.2 $
 * $Date: 2004/02/25 23:11:53 $
 *
 */


#ifndef __NZBQUEUEMESSAGECONTROL_H__
#define __NZBQUEUEMESSAGECONTROL_H__

#include "deque"
#include "Thread.h"
#include "Coordinator.h"
#include "Options.h"
#include "NZBQueue.h"

#define NZBMESSAGEQUEUESIZE 	512
#define NZBREQUESTFILENAMESIZE	512

#define NZBREQUESTPASSWORDSIZE	32

namespace NZBMessageRequest
{
    enum
    {
        eNewDownload = 1,
        ePause,
        eUnPause,
        eListDownloads,
		ePing
    };
}

struct SNZBQueueRequest
{
    long	m_iId;     /* message type, must be > 0 */
    int		m_iType;
	char	m_szFileName[ NZBREQUESTFILENAMESIZE ];
	char	m_szPassword[ NZBREQUESTPASSWORDSIZE ];
};

class NZBQueueCoordinator;

class NZBQueueMessageControl : public Thread
{
    NZBQueueCoordinator*	m_pQueueCoordinator;
	NetAddress*				m_pNetAddress;
	Connection*				m_pConnection;
	char*					m_szPassword;
	int						m_iPort;
public:
							NZBQueueMessageControl();
							~NZBQueueMessageControl();
	void					run();
	void					SetQueueCoordinator( NZBQueueCoordinator* pCoordinator ) { m_pQueueCoordinator = pCoordinator; }
};

#endif

==> nzbget-0.2.2.tar.gz: nzbget-0.2.2/NZBQueueMessageControl.h <==
/*
 *  This file if part of nzbget
 *
 *  Copyright (C) 2005  Bo Cordes Petersen <placebodk@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Revision: 1.6 $
 * $Date: 2005/07/06 18:34:34 $
 *
 */


#ifndef __NZBQUEUEMESSAGECONTROL_H__
#define __NZBQUEUEMESSAGECONTROL_H__

#include "deque"
#include "Thread.h"
#include "Coordinator.h"
#include "Options.h"
#include "NZBQueue.h"
#include "NZBClientServerMessageBase.h"

class NZBQueueCoordinator;

class NZBQueueMessageControl : public Thread, public NZBClientServerMessageBase
{
    NZBQueueCoordinator*	m_pQueueCoordinator;
	NetAddress*				m_pNetAddress;
	Connection*				m_pConnection;
	char*					m_szPassword;
	int						m_iPort;
public:
							NZBQueueMessageControl();
							~NZBQueueMessageControl();
	void					Run();
	void					SetQueueCoordinator( NZBQueueCoordinator* pCoordinator ) { m_pQueueCoordinator = pCoordinator; }
};

#endif
